Meter

Trait Meter 

pub trait Meter {
    type Nested<'a>: Meter
       where Self: 'a;

    // Required methods
    fn nest(&mut self) -> Result<Self::Nested<'_>, MeterError>;
    fn charge(&mut self, amount: usize) -> Result<(), MeterError>;
}
A trait for tracking the resource limits consumed while serializing a value.

Required Associated Types

type Nested<'a>: Meter where Self: 'a

Required Methods

fn nest(&mut self) -> Result<Self::Nested<'_>, MeterError>

Produce a new meter for nested contexts, consuming one unit of nesting budget.

fn charge(&mut self, amount: usize) -> Result<(), MeterError>

Charge amount units against the remaining size budget.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Meter for LocalMeter<'_>

Source

type Nested<'a> = LocalMeter<'a> where Self: 'a

Source

impl Meter for Unmetered

Source

type Nested<'a> = Unmetered where Self: 'a